@@ -185,7 +185,7 @@ random_port = function(port = 4321L, host = '127.0.0.1', n = 20) {
 }
 
 port_available = function(port, host = '127.0.0.1') {
-  tmp = try(startServer(host, port, list()), silent = TRUE)
+  tmp = try(startServer(host, port, list(), quiet = TRUE), silent = TRUE)
   if (inherits(tmp, 'try-error')) return(FALSE)
   stopServer(tmp)
   TRUE
